@@ -17,6 +17,12 @@ set_env_ruby
 
 install_deps
 
+# TODO: move this to shared/shlib/set_env.sh
+export JAVA_HOME="/opt/java/jdk21"
+export SOURCE_VERSION=21
+export TARGET_VERSION=21
+# END TODO
+export CI=1
 echo "Running specs"
 bundle exec rake spec
 test_status=$?
