@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,6 +15,7 @@
 
 $:.unshift File.join(File.dirname(__FILE__), "..", "lib")
 require "benchmark"
+require 'bson'
 
 def benchmark!
   count = 1_000_000
