@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -254,23 +255,37 @@ describe BSON::Int32 do
     end
   end
 
+  describe '#as_json' do
+    let(:object) { described_class.new(42) }
+
+    it 'returns an Integer' do
+      expect(object.as_json).to eq 42
+    end
+
+    it_behaves_like "a JSON serializable object"
+  end
+
   describe '#as_extended_json' do
+    let(:object) { described_class.new(42) }
+
     context 'canonical mode' do
-      it 'returns $numberInt' do
-        described_class.new(42).as_extended_json.should == {'$numberInt' => '42'}
+      it 'returns a Hash with key $numberInt' do
+        expect(object.as_extended_json).to eq({ '$numberInt' => '42' })
       end
     end
 
     context 'relaxed mode' do
-      it 'returns integer' do
-        described_class.new(42).as_extended_json(mode: :relaxed).should == 42
+      it 'returns an Integer' do
+        expect(object.as_extended_json(mode: :relaxed)).to eq 42
       end
     end
 
     context 'legacy mode' do
-      it 'returns integer' do
-        described_class.new(42).as_extended_json(mode: :legacy).should be 42
+      it 'returns an Integer' do
+        expect(object.as_extended_json(mode: :legacy)).to eq 42
       end
     end
+
+    it_behaves_like "an Extended JSON serializable object"
   end
 end
