@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,17 +17,18 @@ require "spec_helper"
 
 describe BSON::MinKey do
 
-  describe "#as_json" do
+  describe "#as_extended_json" do
 
     let(:object) do
       described_class.new
     end
 
     it "returns the binary data plus type" do
-      expect(object.as_json).to eq({ "$minKey" => 1 })
+      expect(object.as_extended_json).to eq({ "$minKey" => 1 })
     end
 
-    it_behaves_like "a JSON serializable object"
+    it_behaves_like 'an Extended JSON serializable object'
+    it_behaves_like '#as_json calls #as_extended_json'
   end
 
   describe "#==" do
