@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -220,13 +221,24 @@ describe BSON::ObjectId do
       described_class.new
     end
 
-    it "returns the object id with $oid key" do
-      expect(object.as_json).to eq({ "$oid" => object.to_s })
+    it "returns the object id as a string" do
+      expect(object.as_json).to eq(object.to_s)
     end
 
     it_behaves_like "a JSON serializable object"
   end
 
+  describe "#as_extended_json" do
+
+    let(:object) do
+      described_class.new
+    end
+
+    it "returns the object id with $oid key" do
+      expect(object.as_extended_json).to eq({ "$oid" => object.to_s })
+    end
+  end
+
   describe "::BSON_TYPE" do
 
     it "returns 0x07" do
@@ -311,7 +323,7 @@ describe BSON::ObjectId do
       it "raises an error" do
         expect {
           described_class.from_string("asadsf")
-        }.to raise_error(BSON::ObjectId::Invalid)
+        }.to raise_error(BSON::Error::InvalidObjectId)
       end
     end
   end
@@ -592,7 +604,48 @@ describe BSON::ObjectId do
     it "raises an exception on serialization" do
       expect {
         hash.to_bson
-      }.to raise_error(BSON::InvalidKey)
+      }.to raise_error(BSON::Error::InvalidKey)
+    end
+  end
+
+  context 'when the counter wraps' do
+    before do
+      BSON::ObjectId._generator.reset_counter(0xFFFFFF)
+    end
+
+    let(:before) { BSON::ObjectId.new }
+    let(:after) { BSON::ObjectId.new }
+
+    it 'resets the counter portion to 0' do
+      expect(before._counter_part).to be == "ffffff"
+      expect(after._counter_part).to be == "000000"
+    end
+  end
+
+  context 'when the timestamp is larger than a 32-bit integer' do
+    let(:distant_future) { Time.at(2 ** 32) }
+
+    before do
+      allow(Time).to receive(:now).and_return(distant_future)
+    end
+
+    let(:object_id) { BSON::ObjectId.new }
+
+    it 'wraps the timestamp to 0' do
+      expect(object_id.to_time).to be == Time.at(0)
+    end
+  end
+
+  context 'when fork changes the pid' do
+    before do
+      skip 'requires Process.fork' unless Process.respond_to?(:fork)
+    end
+
+    let(:parent_id) { BSON::ObjectId.new }
+    let(:child_id) { Utils.perform_in_child { BSON::ObjectId.new } }
+
+    it 'changes the process portion of the object-id' do
+      expect(child_id._process_part).not_to be == parent_id._process_part
     end
   end
 end
