@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -106,28 +107,24 @@ describe Symbol do
 
   describe "#to_bson_key" do
 
-    context "when validating keys" do
-
-      let(:symbol) do
-        :'$testing.testing'
-      end
-
-      it "raises an exception" do
-        expect {
-          symbol.to_bson_key(true)
-        }.to raise_error(BSON::String::IllegalKey)
-      end
+    let(:symbol) do
+      :'$testing.testing'
     end
 
-    context "when not validating keys" do
-
-      let(:symbol) do
-        :'$testing.testing'
-      end
-
-      it "allows invalid keys" do
-        expect(symbol.to_bson_key).to eq(symbol)
-      end
+    it "returns the key" do
+      expect(symbol.to_bson_key).to eq(symbol)
     end
   end
+
+  describe '#as_extended_json' do
+    let(:object) do
+      :foobar
+    end
+
+    it 'returns the binary data plus type' do
+      expect(object.as_extended_json).to eq({ '$symbol' => 'foobar' })
+    end
+
+    it_behaves_like 'an Extended JSON serializable object'
+  end
 end
