@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,4 +26,11 @@ describe TrueClass do
     it_behaves_like "a bson element"
     it_behaves_like "a serializable bson element"
   end
+
+  describe '#as_extended_json' do
+    let(:object) { true }
+
+    it_behaves_like '#as_extended_json returns self'
+    it_behaves_like 'an Extended JSON serializable object'
+  end
 end
