@@ -1,3 +1,4 @@
+# rubocop:todo all
 require 'spec_helper'
 require 'runners/common_driver'
 
@@ -25,8 +26,12 @@ describe 'Driver common bson tests' do
             expect(test.from_json_string).to eq(test.object)
           end
 
+          it 'serializes to a string', if: test.to_ext_json? do
+            expect(test.document_as_extended_json).to eq(test.ext_json)
+          end
+
           it 'creates the correct extended json document from the decoded object', if: test.to_ext_json? do
-            expect(test.document_as_json).to eq(test.ext_json)
+            expect(test.document_as_extended_json).to eq(test.ext_json)
           end
 
           it 'parses the string value to the same value as the decoded document', if: test.from_string? do
@@ -63,9 +68,9 @@ describe 'Driver common bson tests' do
 
           let(:valid_errors) do
             [
-              BSON::Decimal128::InvalidString,
-              BSON::Decimal128::InvalidRange,
-              BSON::Decimal128::UnrepresentablePrecision,
+              BSON::Error::InvalidDecimal128String,
+              BSON::Error::InvalidDecimal128Range,
+              BSON::Error::UnrepresentablePrecision,
             ]
           end
 
