@@ -1,3 +1,4 @@
+# rubocop:todo all
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -63,6 +64,28 @@ shared_examples_for "a JSON serializable object" do
   end
 end
 
+shared_examples_for "an Extended JSON serializable object" do
+
+  it "serializes the Extended JSON from #as_extended_json" do
+    expect(object.to_extended_json).to eq(object.as_extended_json.to_json)
+  end
+end
+
+shared_examples_for '#as_extended_json returns self' do
+
+  it 'returns self' do
+    expect(object.as_extended_json).to eq(object)
+  end
+end
+
+shared_examples_for '#as_json calls #as_extended_json' do
+
+  it 'calls #as_extended_json' do
+    expect(object).to receive(:as_extended_json).with(no_args)
+    object.as_json
+  end
+end
+
 shared_examples_for "immutable when frozen" do |block|
 
   context "when the document is frozen" do
@@ -122,7 +145,7 @@ shared_examples_for "a validated BSON key" do
     end
   end
 
-  context "when the string is invalid" do
+  context "when the string has dots/dollars" do
 
     context "when the string starts with $" do
 
@@ -130,10 +153,10 @@ shared_examples_for "a validated BSON key" do
         "$testing"
       end
 
-      it "raises an exception" do
+      it "does not raise an exception" do
         expect {
           validated
-        }.to raise_error(BSON::String::IllegalKey)
+        }.to_not raise_error
       end
     end
 
@@ -143,10 +166,10 @@ shared_examples_for "a validated BSON key" do
         "testing.testing"
       end
 
-      it "raises an exception" do
+      it "does not raise an exception" do
         expect {
           validated
-        }.to raise_error(BSON::String::IllegalKey)
+        }.to_not raise_error
       end
     end
   end
